function esn = compileEsnFromSpec( esnSpec )
% COMPILEESNFROMSPEC Generates ESN according to given spec
% by Mantas Lukosevicius

% --------- read values (or set default ones)
size = esnSpec.size;

spectralRadius = esnSpec.spectralRadius;

if isfield( esnSpec, 'connectivity' ) ~= 1
    connectivity = 10;
else
	connectivity = esnSpec.connectivity;
end

if connectivity > 1.0
    % absolute -> relative
    connectivity = connectivity ./ size; 
end

inSize = esnSpec.inSize;

if isfield( esnSpec, 'inScaling' ) ~= 1 && isfield( esnSpec, 'inScale' ) ~= 1
    inScaling = 1.0;
elseif isfield( esnSpec, 'inScaling' ) == 1
	inScaling = esnSpec.inScaling;
else
	inScaling = esnSpec.inScale;
end

if isfield( esnSpec, 'inConnectivity' ) ~= 1
    inConnectivity = 1;
else
	inConnectivity = esnSpec.inConnectivity;
end

if inConnectivity > 1.0
    % absolute -> relative
    inConnectivity = inConnectivity ./ size; 
end

if isfield( esnSpec, 'biasScaling' ) ~= 1
    biasScaling = inScaling;
else
	biasScaling = esnSpec.biasScaling;
end

outSize = esnSpec.outSize;

if isfield( esnSpec, 'outScaling' ) ~= 1
    outScaling = 1.0;
else
	outScaling = esnSpec.outScaling;
end

if isfield( esnSpec, 'outConnectivity' ) ~= 1
    outConnectivity = 1;
else
	outConnectivity = esnSpec.outConnectivity;
end
if outConnectivity > 1.0
    % absolute -> relative
    outConnectivity = outConnectivity ./ size; 
end

% --------- generate weights
% W
esn.W = randReservoir( size, connectivity, spectralRadius ); 

% Win
Win = randWeights( size, inSize, inScaling, inConnectivity );
% biases
esn.Win = [ randWeights( size, 1, biasScaling ), Win ];

% Wout
[esn.Wout esn.WoutMask] = ...
	randWeights( outSize, 1 + inSize + size, outScaling, outConnectivity );

% Wofb - TODO?

% --------- Set default activation functions

% reservoir activation function
if isfield( esnSpec, 'activation' ) ~= 1
    esn.activation = tanhActivation();
else
	esn.activation = esnSpec.activation;
end

% output activation function
if isfield( esnSpec, 'outActivation' ) ~= 1
    esn.outActivation = linearActivation();
else
	esn.outActivation = esnSpec.outActivation;
end

% reservoir leaking rate
if isfield( esnSpec, 'leakingRate' ) ~= 1
    esn.leakingRate = 1;
else
	esn.leakingRate = esnSpec.leakingRate;
end

% reservoir noise lever
if isfield( esnSpec, 'noiseLevel' ) ~= 1
    esn.noiseLevel = 0;
else
	esn.noiseLevel = esnSpec.noiseLevel;
end

% --------- Set default state
esn.state = zeros( size, 1 );
esn.lastIn = zeros( inSize, 1 );
esn.lastOut = zeros( outSize, 1 );

