function [events, interm ] = detectRrEvents0( y )
%detectRrEvents1 detects fetal ECG R events form the indicator signal
% for PhysioNet 2013 challenge
% by Mantas Lukosevicius 2013

	% RR interval duration is assumed to have normal disribution 
	% from cinc_total_rr_hist.m: RR mean = 442.1759, std = 45.99
% 	rrMean = 442;
	rrStd = 46;
	% from cinc_total_75_rr_hist.m: RR mean = 424.8335, std = 83.6907 
	% from cinc_total_rr_hist_ign.m: RR mean = 423.8379, std = 39.867
	%  (has outliers up to ~5000 in A54)
	rrMean = 424;
%	rrStd = 40;
% 	rrStd = 83.7;
	
	% change of RR interval duration is assumed to have normal disribution 
	% from cinc_total_drr_hist.m: dRR mean = -0.06497, std = 18.8144
	%drrMean = 0;
	%drrStd = 19;
	% from cinc_total_75_rr_hist.m: RR mean = 424.8335, std = 83.6907 
	%  (has outliers up to ~5000 in A54)

	runLength = size( y, 2 );
	
	interm = y;
	
	rrMax = 2*rrMean; % ~0.9s
	
	% to regain the rythm once it's lost
% 	broadFactor = 0.17;
% 	broadPdf = ones(1, rrMax );
	
	broadFactor = 0.35;
	broadPdf = [2:2:rrMax rrMax:-2:2]/rrMax;

	% to keep the rithm
	rrPdf = normpdf( 1:rrMax, rrMean, rrStd );
	rrPdf = rrPdf / max( rrPdf );
	
	rrPdf = ( rrPdf + broadPdf * broadFactor) / (1+broadFactor);

	[ v, i ]  = max( y(1:rrMean+2*rrStd) );

	events = i;
	
	while i + rrMean+rrStd < runLength
		if i + rrMax > runLength
			rrMax = runLength - i; % quick'n'dirty
			[v, di] = max( y(i+1:i+rrMax) .* rrPdf(1:rrMax) );
		else
			[v, di] = max( y(i+1:i+rrMax) .* rrPdf );
		end
		interm(i+2*rrStd:i+rrMax) = y(i+2*rrStd:i+rrMax) .* rrPdf(2*rrStd:rrMax);
		i = i + di;
		events = [events, i];
		
	end

end