% Fetal ECG detection
% for PhysioNet 2013 challenge data B
% by Mantas Lukosevicius & Vaidotas Marozas 2013

clear all
close all
clc
tic

addpath('SMOORT');
addpath('SMOORT\utils');

filtering = 1;

plotting = 1;	spacing = 5;
saving = 1;		saveExt = '.fqrs_entry1';

% params of data
fs = 1000; % sampling frequency
inSize = 4;
outSize = 1;
introLength = 0; % not used anymore
targetDelay = 0;

dataPreprocess = @loadPreprocBData5;
meanMRR = 1.25;
uStd = 1.; % - pre-mqrs removal
uTanh = 1;
dataPostprocess = @detectRrEvents0;% @detectEvents1;% 

disp '======='

%% Create filter
if filtering
	%% Bandpass filtering   
	Fstop1 = 5;               % First Stopband Frequency
	Fpass1 = 12;              % First Passband Frequency
	Fpass2 = 45;              % Second Passband Frequency
	Fstop2 = 49;              % Second Stopband Frequency
	Dstop1 = 0.01;            % First Stopband Attenuation
	Dpass  = 0.057501127785;  % Passband Ripple
	Dstop2 = 0.01;            % Second Stopband Attenuation
	dens   = 20;              % Density Factor
	% Calculate the order from the parameters using FIRPMORD.
	[N, Fo, Ao, W] = firpmord([Fstop1 Fpass1 Fpass2 Fstop2]/(fs/2), [0 1 ...
							  0], [Dstop1 Dpass Dstop2]);
	% Calculate the coefficients using the FIRPM function.
	b  = firpm(N, Fo, Ao, W, {dens});
    %freqz(b,1,10000,1000)
else
	b = [];
end

%% load the ESN
load 'trained_esn_1000.mat';

% record starting state (initialized with long zero input)
besn = resetState( besn );
besn = run( besn, zeros(inSize,500) );
startState = state( besn );


%% ========= 'test' ESN on the B datasets
disp --------
for dataFileNr = 0:99;

	[u, data] = dataPreprocess( ...
		dataFileNr, b, uStd, uTanh, meanMRR );

	%% test ESN
	% no intro
	besn = state( besn, startState );

	[besn y states] = run( besn, u ); 
	
	%% Post processing
	fqrs_det = dataPostprocess( y );

	%% save results
	if saving
		if dataFileNr < 10
			dataFileName = ['b0' num2str(dataFileNr) ];
		else
			dataFileName = ['b' num2str(dataFileNr) ];
		end
		dataFilePath = ['duomenys\', dataFileName, saveExt];
		
		save( dataFilePath, 'fqrs_det', '-ASCII' );
	end
	
	%% plot
	if plotting
		set( figure(800+dataFileNr), 'WindowStyle', 'docked' );
		stem( fqrs_det, ones(size(fqrs_det))*4*spacing, '.r');
		hold on
		for lead = 1:inSize
			%plot( data_norm(lead,:) + (inSize-lead)*spacing,'g' );
			plot( data(lead,:) + (inSize-lead)*spacing,'g' );
			plot( u(lead,:) + (inSize-lead)*spacing );
		end
		axis tight
		hold off
	end
	
end

toc

%playBeep;
